@@ -1,5 +1,5 @@
 +{
-   locale_version => 1.17,
+   locale_version => 1.20,
    entry => <<'ENTRY', # for DUCET v8.0.0
 0161      ; [.1E0D.0020.0002] # LATIN SMALL LETTER S WITH CARON
 0073 030C ; [.1E0D.0020.0002] # LATIN SMALL LETTER S WITH CARON
@@ -11,8 +11,6 @@
 007A 030C ; [.1E0F.0020.0002] # LATIN SMALL LETTER Z WITH CARON
 017D      ; [.1E0F.0020.0008] # LATIN CAPITAL LETTER Z WITH CARON
 005A 030C ; [.1E0F.0020.0008] # LATIN CAPITAL LETTER Z WITH CARON
-0077      ; [.1E5E.0021.0002] # LATIN SMALL LETTER W
-0057      ; [.1E5E.0021.0008] # LATIN CAPITAL LETTER W
 00F5      ; [.1E76.0020.0002] # LATIN SMALL LETTER O WITH TILDE
 006F 0303 ; [.1E76.0020.0002] # LATIN SMALL LETTER O WITH TILDE
 00D5      ; [.1E76.0020.0008] # LATIN CAPITAL LETTER O WITH TILDE
